@@ -113,7 +113,7 @@ def redisdb(request, redis_proc):
         config.redis.port,
         config.redis.db,
     )
-    request.addfinalizer(redis_client.flushall)
+    request.addfinalizer(redis_client.flushdb)
     return redis_client
 
 
@@ -274,7 +274,16 @@ def mysql_proc(request):
     return mysql_executor
 
 
-def mysqldb_fixture_factory(scope):
+def mysqldb_fixture_factory(scope='session'):
+    """
+    Factory. Create connection to mysql. If you want you can give a scope,
+    default is 'session'.
+
+    :param str scope: scope (session, function, module, etc.)
+    :rtype: func
+    :returns: function ``mysqldb_fixture`` with suit scope
+    """
+
     @pytest.fixture(scope)
     def mysqldb_fixture(request, mysql_proc):
         config = get_config(request)
@@ -298,7 +307,11 @@ def mysqldb_fixture_factory(scope):
             mysql_conn.close()
 
         request.addfinalizer(drop_database)
+
         return mysql_conn
 
-mysqldb_session = mysqldb_fixture_factory(scope='session')
+    return mysqldb_fixture
+
+
+mysqldb_session = mysqldb_fixture_factory()
 mysqldb = mysqldb_fixture_factory(scope='function')
